@@ -181,8 +181,20 @@ class BinhostsBase(Cachable):
                         if "update" in cp.sections():
                             self.level = int(cp["update"]["level"])
 
-                            #TODO this is for debugging
-                            # self.level = 2
+                            #DEBUG
+                            # if not "https://mirror.calculate-linux.org/migrate/" in self.host:
+                            #     hosts_mod_levels = {
+
+                            #           "https://ftp.acc.umu.se/mirror/calculate-linux.org" : 1,
+                            #           
+                            #      }
+
+
+                            #     for host in hosts_mod_levels:
+                            #         if host in self.host: 
+                            #             self.level = hosts_mod_levels[host]
+                            #             break
+
 
                         else:
                             self.level = None
@@ -197,6 +209,7 @@ class BinhostsBase(Cachable):
                 self.duration = 0
                 self.outdated = True
                 self.downgraded = True
+                self.level = 0
 
         @property
         def status(self):
